@@ -60,8 +60,11 @@ CONNMODES = {
 CRLF = b"\x0d\x0a"
 DDD = "DD.D"
 DEFAULT_BUFSIZE = 4096
+DEFAULT_PASSWORD = "password"  # nosec
 DEFAULT_PORT = 50010
+DEFAULT_REGION = "eu"
 DEFAULT_SERVER = "localhost"
+DEFAULT_USER = "anon"
 DIRNAME = path.dirname(__file__)
 DISCONNECTED = 0
 DLG = "dlg"
