@@ -1,4 +1,6 @@
 """
+graphview_frame.py
+
 Graphview frame class for PyGPSClient application.
 
 This handles a frame containing a graph of current satellite reception.
@@ -48,6 +50,7 @@ class GraphviewFrame(Frame):
         self.width = kwargs.get("width", def_w)
         self.height = kwargs.get("height", def_h)
         self._body()
+        self._attach_events()
 
         self.bind("<Configure>", self._on_resize)
 
@@ -63,7 +66,25 @@ class GraphviewFrame(Frame):
         )
         self.can_graphview.pack(fill=BOTH, expand=YES)
 
-    def init_graph(self):
+    def _attach_events(self):
+        """
+        Bind events to frame.
+        """
+
+        self.can_graphview.bind("<Double-Button-1>", self._on_legend)
+
+    def _on_legend(self, event):  # pylint: disable=unused-argument
+        """
+        On double-click - toggle legend on/off.
+
+        :param event: event
+        """
+
+        self.__app.frm_settings.show_legend.set(
+            not self.__app.frm_settings.show_legend.get()
+        )
+
+    def init_frame(self):
         """
         Initialise graph view
         """
@@ -88,7 +109,7 @@ class GraphviewFrame(Frame):
                 font=resize_font,
             )
 
-        if self.__app.frm_settings.config["legend"]:
+        if self.__app.frm_settings.config.get("legend_b", 1):
             self._draw_legend()
 
     def _draw_legend(self):
@@ -96,9 +117,9 @@ class GraphviewFrame(Frame):
         Draw GNSS color code legend
         """
 
-        w = self.width / 9
+        w = self.width / 10
         h = self.height / 15
-        resize_font = font.Font(size=min(int(self.height / 25), 10))
+        resize_font = font.Font(size=min(int(self.height / 30), 10))
 
         for i, (_, (gnssName, gnssCol)) in enumerate(GNSS_LIST.items()):
             x = LEG_XOFF + w * i
@@ -132,7 +153,7 @@ class GraphviewFrame(Frame):
             return
 
         w, h = self.width, self.height
-        self.init_graph()
+        self.init_frame()
 
         offset = AXIS_XL + 2
         colwidth = (w - AXIS_XL - AXIS_XR + 1) / siv
