@@ -23,8 +23,7 @@ from tkinter import Button, Entry, Label, Toplevel, W, font
 
 from pynmeagps import haversine
 from pyubx2 import SET, UBX_MSGIDS, UBXMessage, attsiz, atttyp
-from requests import ConnectionError as ConnError
-from requests import HTTPError, JSONDecodeError, get
+from requests import get
 
 from pygpsclient.globals import (
     FIXLOOKUP,
@@ -936,6 +935,26 @@ def ned2vector(n: float, e: float, d: float) -> tuple:
     return dis, hdg
 
 
+def isot2dt(tim: str) -> datetime:
+    """
+    Format datetime from ISO time element.
+
+    :param str tim: iso time from trackpoint
+    :return: datetime
+    :rtype: datetime
+    """
+
+    if tim[-1] == "Z":  # strip timezone label
+        tim = tim[0:-1]
+    if tim[-4] == ".":  # has milliseconds
+        tfm = "%Y-%m-%dT%H:%M:%S.%f"
+    elif tim[-7] == ".":  # has microseconds
+        tfm = "%Y-%m-%dT%H:%M:%S.%f"
+    else:
+        tfm = "%Y-%m-%dT%H:%M:%S"
+    return datetime.strptime(tim, tfm).timestamp()
+
+
 def publicip() -> str:
     """
     Get public IP address from ipinfo REST API.
@@ -947,7 +966,7 @@ def publicip() -> str:
         response = get(PUBLICIP_URL, verify=True, timeout=3)
         response.raise_for_status()
         return response.json().get("ip", "N/A")
-    except (HTTPError, ConnError, JSONDecodeError):
+    except Exception:  # pylint: disable=broad-exception-caught
         return "N/A"
 
 
