@@ -767,8 +767,6 @@ class SettingsFrame(Frame):
                 "sockclienthost_s": self.frm_socketclient.server.get(),
                 "sockclientport_n": self.frm_socketclient.port.get(),
                 "sockclientprotocol_s": self.frm_socketclient.protocol.get(),
-                "sockclientflowinfo_n": self.frm_socketclient.flowinfo.get(),
-                "sockclientscopeid_n": self.frm_socketclient.scopeid.get(),
                 # socket server settings from frm_socketserver
                 "sockserver_b": self.frm_socketserver.socketserving,
                 "sockhost_s": self.frm_socketserver.sock_host.get(),
@@ -884,27 +882,15 @@ class SettingsFrame(Frame):
                     ),
                 ),
                 # Manually edited config settings
-                # (cater for older config file element names without suffices)
                 "mapupdateinterval_n": self.__app.saved_config.get(
-                    "mapupdateinterval_n",
-                    self.__app.saved_config.get(
-                        "mapupdateinterval", MAP_UPDATE_INTERVAL
-                    ),
+                    "mapupdateinterval_n", MAP_UPDATE_INTERVAL
                 ),
                 "defaultport_s": self.__app.saved_config.get(
-                    "defaultport_s",
-                    self.__app.saved_config.get("defaultport", RCVR_CONNECTION),
-                ),
-                "mqapikey_s": self.__app.saved_config.get(
-                    "mqapikey_s",
-                    self.__app.saved_config.get("mqapikey", self.__app.mqapikey),
-                ),
-                "colortags_l": self.__app.saved_config.get(
-                    "colortags_l", self.__app.saved_config.get("colortags", [])
-                ),
-                "ubxpresets_l": self.__app.saved_config.get(
-                    "ubxpresets_l", self.__app.saved_config.get("ubxpresets", [])
+                    "defaultport_s", RCVR_CONNECTION
                 ),
+                "mqapikey_s": self.__app.saved_config.get("mqapikey_s", ""),
+                "colortags_l": self.__app.saved_config.get("colortags_l", []),
+                "ubxpresets_l": self.__app.saved_config.get("ubxpresets_l", []),
             }
             return config
         except (KeyError, ValueError, TypeError, TclError) as err:
