@@ -1,4 +1,6 @@
 """
+spectrum_frame.py
+
 Spectrum Analysis frame class for PyGPSClient application.
 
 This handles a frame containing a spectrum analysis chart from
@@ -14,10 +16,11 @@ Created on 23 Dec 2022
 from math import ceil
 from tkinter import BOTH, YES, Canvas, Frame, font
 
-from pyubx2 import SET, UBXMessage
+from pyubx2 import UBXMessage
 
 from pygpsclient.globals import BGCOL, FGCOL, GNSS_LIST, SPECTRUMVIEW, WIDGETU2
-from pygpsclient.strings import DLGNOMONSPAN, MONSPANERROR
+from pygpsclient.helpers import setubxrate
+from pygpsclient.strings import DLGENABLEMONSPAN, DLGNOMONSPAN, DLGWAITMONSPAN
 
 # Graph dimensions
 RESFONT = 24  # font size relative to widget size
@@ -55,6 +58,7 @@ RF_LIST = {
     4: "dodgerblue",
     5: "darkorange",
 }
+ACTIVE = ""
 
 
 class SpectrumviewFrame(Frame):
@@ -83,7 +87,7 @@ class SpectrumviewFrame(Frame):
         self._maxdb = MAX_DB
         self._minhz = MIN_HZ
         self._maxhz = MAX_HZ
-        self._monspan_enabled = False
+        self._monspan_status = DLGENABLEMONSPAN
         self._pending_confs = {}
         self._showrf = True
         self._chartpos = None
@@ -112,7 +116,7 @@ class SpectrumviewFrame(Frame):
         self.can_spectrumview.bind("<Button-1>", self._on_click)
         self.can_spectrumview.bind("<Double-Button-1>", self._toggle_rf)
 
-    def init_graph(self):
+    def init_frame(self):
         """
         Initialise spectrum chart.
         """
@@ -177,13 +181,12 @@ class SpectrumviewFrame(Frame):
         )
 
         # display 'enable MON-SPAN' warning
-        if not self._monspan_enabled:
-            self.can_spectrumview.create_text(
-                self.width / 2,
-                self.height / 2,
-                text=MONSPANERROR,
-                fill="orange",
-            )
+        self.can_spectrumview.create_text(
+            self.width / 2,
+            self.height / 2,
+            text=self._monspan_status,
+            fill="orange",
+        )
 
     def reset(self):
         """
@@ -194,28 +197,18 @@ class SpectrumviewFrame(Frame):
         self._chartpos = None
         self.can_spectrumview.delete("all")
         self.update_frame()
-        self.enable_MONSPAN(self.winfo_ismapped())
 
-    def enable_MONSPAN(self, status: bool):
+    def enable_messages(self, status: bool):
         """
-        Enable/disable UBX MON-SPAN (b'\x0a\x31') message.
+        Enable/disable UBX MON-SPAN message.
 
         :param bool status: 0 = off, 1 = on
         """
 
-        msg = UBXMessage(
-            "CFG",
-            "CFG-MSG",
-            SET,
-            msgClass=0x0A,
-            msgID=0x31,
-            rateUART1=status,
-            rateUART2=status,
-            rateUSB=status,
-        )
-        self.__app.gnss_outqueue.put(msg.serialize())
+        setubxrate(self.__app, "MON-SPAN", status)
         for msgid in ("ACK-ACK", "ACK-NAK"):
             self._set_pending(msgid, SPECTRUMVIEW)
+        self._monspan_status = DLGWAITMONSPAN
 
     def _set_pending(self, msgid: int, ubxfrm: int):
         """
@@ -249,7 +242,8 @@ class SpectrumviewFrame(Frame):
                 anchor="s",
             )
             self._pending_confs.pop("ACK-NAK")
-            self._monspan_enabled = False
+            self._monspan_status = DLGNOMONSPAN
+            self.init_frame()
 
         if self._pending_confs.get("ACK-ACK", False):
             self._pending_confs.pop("ACK-ACK")
@@ -262,15 +256,15 @@ class SpectrumviewFrame(Frame):
         one item per RF block.
         """
 
-        self._monspan_enabled = True
         rfblocks = self.__app.gnss_status.spectrum_data
         if len(rfblocks) == 0:
             return
+        self._monspan_status = ACTIVE
 
         specxy, self._minhz, self._maxhz, self._mindb, self._maxdb = self._get_limits(
             rfblocks
         )
-        self.init_graph()
+        self.init_frame()
 
         # plot frequency band markers
         if self._showrf:
