@@ -39,6 +39,7 @@ CONFIGRXM = "{} polled, {} key(s) loaded"
 CONFIGTITLE = "Config File"
 ENDOFFILE = "End of file reached"
 FILEOPENERROR = "Error opening file {}"
+INACTIVE_TIMEOUT = "Inactivity timeout"
 LOADCONFIGBAD = "Configuration not loaded {} {}, using defaults"
 LOADCONFIGOK = "Configuration loaded {}"
 LOADCONFIGNONE = "Configuration file not found {}, using defaults"
@@ -103,6 +104,7 @@ LBLDURATIONS = "Duration (s)"
 LBLGGAFIXED = "Fixed Reference"
 LBLGGALIVE = "Receiver"
 LBLJSONLOAD = "Load Keys From JSON"
+LBLLANIP = "LAN IP"
 LBLNTRIPCONFIG = "NTRIP Client"
 LBLNTRIPGGAINT = "GGA Interval s"
 LBLNTRIPMOUNT = "Mountpoint"
@@ -114,7 +116,8 @@ LBLNTRIPUSER = "User"
 LBLNTRIPVERSION = "Version"
 LBLPRESET = "Preset UBX Configuration Commands"
 LBLPROTDISP = "Protocols Shown"
-LBLSERVERHOST = "Host"
+LBLPUBLICIP = "Public IP"
+LBLSERVERHOST = "Host IP"
 LBLSERVERMODE = "Mode"
 LBLSERVERPORT = "Port"
 LBLSET = "Settings"
